@@ -1,9 +1,10 @@
-/* example-begin popt.c */
 
+/*** block  from ../../docs/manual/basics-init.xml ***/
 #include <gst/gst.h>
 
 int
-main(int argc, char *argv[])
+main (int   argc,
+      char *argv[])
 {
   gboolean silent = FALSE;
   gchar *savefile = NULL;
@@ -21,4 +22,3 @@ main(int argc, char *argv[])
 
   return 0;
 }
-/* example-end popt.c */
